@@ -27,7 +27,9 @@ fitspropmap = {
         'subtype': 'sub_type', 'imagetyp': 'sub_type',
         'temperat': 'temperature', 'temp': 'temperature', 'ccd-temp': 'temperature',
         'stackcnt': 'nsubs',
-        'xpixsz': 'pixel_width', 'ypixsz': 'pixel_height'
+        'xpixsz': 'pixel_width', 'ypixsz': 'pixel_height',
+        'xbinning': 'binning',
+        'ybinning': 'binning'
         }
 
 ''' used to map from image prop names to fits name if they are difference; 
@@ -66,11 +68,22 @@ default_props = {
     'nsubs': None}
 
 # map from possible found filter names to the Jocular scheme
+# filter_map = {'r': 'R', 'g': 'G', 'b': 'B', 'red': 'R', 'green': 'G', 
+#     'blue': 'B', 'dark': 'dark',  
+#     'ha': 'Ha', 'halpha': 'Ha', 'h': 'Ha',
+#     'sii': 'SII', 's': 'SII',
+#     'oiii': 'OIII', 'o': 'OIII',
+#     'spect': 'spec', 'l': 'L', 'lum': 'L', 'no': 'L', 'none': 'L'}
+
 filter_map = {'r': 'R', 'g': 'G', 'b': 'B', 'red': 'R', 'green': 'G', 
     'blue': 'B', 'dark': 'dark',  
-    'ha': 'Ha', 'halpha': 'Ha', 'sii': 'SII', 'oiii': 'OIII',
+    'ha': 'H', 'halpha': 'H', 'h': 'H',
+    's': 'S', 'sii': 'S', 's': 'S',
+    'oiii': 'O', 'o': 'O',
     'spect': 'spec', 'l': 'L', 'lum': 'L', 'no': 'L', 'none': 'L'}
 
+
+
 def convert_fits_props(hdr):
     ''' form dict from Image prop to value but don't include unknown FITs props
     '''
@@ -98,6 +111,8 @@ def save_image(data=None, path=None, capture_props=None):
         capture_props is a dict to save e.g. gain, offset, expo
     '''
 
+    # print('save image capture props', capture_props)
+
     dupes = [
         ('SUBTYPE', 'IMAGETYP'),
         ('EXPOSURE', 'EXPTIME'), 
@@ -189,7 +204,8 @@ class Image:
             raise Exception('not a fits file {:}'.format(path))
 
         try:
-            with fits.open(path) as hdu1:
+            # added in v0.5.6 ignore missing end
+            with fits.open(path, ignore_missing_end=True) as hdu1:
                 hdu1.verify('silentfix')
                 hdr = hdu1[0].header
                 # we check that the image is readable if necessary
@@ -241,8 +257,8 @@ class Image:
         try:
             # is it a master?
             self.is_master = self.name.startswith('master') or \
-                fits_props.get('sub_type', '').lower().startswith('master') or \
-                fits_props.get('nsubs', 0) > 1
+                fits_props.get('sub_type', '').lower().startswith('master') # or \
+                # fits_props.get('nsubs', 0) > 1
 
         except Exception as e:
             logger.exception(e)
@@ -402,15 +418,32 @@ class Image:
         return props
 
     def get_image(self):
+        ''' Changed to represent subs as float32
+        '''
         if self.image is None:
             try:
                 with fits.open(self.path) as hdu:
                     bp = hdu[0].header['BITPIX']
-                    if bp < 0:
-                        self.image = hdu[0].data
-                    else:
-                        self.image = hdu[0].data / 2 ** bp
+                    self.image = np.array(hdu[0].data, dtype=np.float32)
+                    #self.image = np.array(hdu[0].data, dtype=np.float64)
+                    if bp > 0:
+                        self.image /= (2 ** bp)
             except Exception as e:
                 logger.warning('cannot read image data from {:} ({:})'.format(self.path, e))
         return self.image
 
+    # def get_image(self):
+    #     ''' If anywhere, this is the place to ensure it is float32
+    #     '''
+    #     if self.image is None:
+    #         try:
+    #             with fits.open(self.path) as hdu:
+    #                 bp = hdu[0].header['BITPIX']
+    #                 if bp < 0:
+    #                     self.image = hdu[0].data
+    #                 else:
+    #                     self.image = hdu[0].data / 2 ** bp
+    #         except Exception as e:
+    #             logger.warning('cannot read image data from {:} ({:})'.format(self.path, e))
+    #     return self.image
+
